@@ -11,6 +11,8 @@ use crate::http::request::Request;
 use crate::http::response::Response;
 use crate::http::service::HttpService;
 use crate::service::{boxed, IntoService, IntoServiceFactory, Service, ServiceFactory};
+use crate::time::{Millis, Seconds};
+use crate::util::PoolId;
 
 /// A http service builder
 ///
@@ -18,12 +20,10 @@ use crate::service::{boxed, IntoService, IntoServiceFactory, Service, ServiceFac
 /// builder-like pattern.
 pub struct HttpServiceBuilder<T, S, X = ExpectHandler, U = UpgradeHandler<T>> {
     keep_alive: KeepAlive,
-    client_timeout: u64,
-    client_disconnect: u64,
-    handshake_timeout: u64,
-    lw: u16,
-    read_hw: u16,
-    write_hw: u16,
+    client_timeout: Millis,
+    client_disconnect: Seconds,
+    handshake_timeout: Millis,
+    pool: PoolId,
     expect: X,
     upgrade: Option<U>,
     on_connect: Option<Rc<dyn Fn(&T) -> Box<dyn DataFactory>>>,
@@ -35,13 +35,11 @@ impl<T, S> HttpServiceBuilder<T, S, ExpectHandler, UpgradeHandler<T>> {
     /// Create instance of `ServiceConfigBuilder`
     pub fn new() -> Self {
         HttpServiceBuilder {
-            keep_alive: KeepAlive::Timeout(5),
-            client_timeout: 3,
-            client_disconnect: 3,
-            handshake_timeout: 5,
-            lw: 1024,
-            read_hw: 8 * 1024,
-            write_hw: 8 * 1024,
+            keep_alive: KeepAlive::Timeout(Seconds(5)),
+            client_timeout: Millis::from_secs(3),
+            client_disconnect: Seconds(3),
+            handshake_timeout: Millis::from_secs(5),
+            pool: PoolId::P1,
             expect: ExpectHandler,
             upgrade: None,
             on_connect: None,
@@ -77,7 +75,7 @@ where
         self
     }
 
-    /// Set server client timeout in seconds for first request.
+    /// Set server client timeout for first request.
     ///
     /// Defines a timeout for reading client request header. If a client does not transmit
     /// the entire set headers within this time, the request is terminated with
@@ -86,8 +84,8 @@ where
     /// To disable timeout set value to 0.
     ///
     /// By default client timeout is set to 3 seconds.
-    pub fn client_timeout(mut self, val: u16) -> Self {
-        self.client_timeout = val as u64;
+    pub fn client_timeout(mut self, timeout: Seconds) -> Self {
+        self.client_timeout = timeout.into();
         self
     }
 
@@ -99,35 +97,43 @@ where
     /// To disable timeout set value to 0.
     ///
     /// By default disconnect timeout is set to 3 seconds.
-    pub fn disconnect_timeout(mut self, val: u16) -> Self {
-        self.client_disconnect = val as u64;
+    pub fn disconnect_timeout(mut self, timeout: Seconds) -> Self {
+        self.client_disconnect = timeout;
         self
     }
 
-    /// Set server ssl handshake timeout in seconds.
+    /// Set server ssl handshake timeout.
     ///
     /// Defines a timeout for connection ssl handshake negotiation.
     /// To disable timeout set value to 0.
     ///
     /// By default handshake timeout is set to 5 seconds.
-    pub fn ssl_handshake_timeout(mut self, val: u16) -> Self {
-        self.handshake_timeout = val as u64;
+    pub fn ssl_handshake_timeout(mut self, timeout: Seconds) -> Self {
+        self.handshake_timeout = timeout.into();
         self
     }
 
+    /// Set memory pool.
+    ///
+    /// Use specified memory pool for memory allocations. By default P1
+    /// memory pool is used.
+    pub fn memory_pool(mut self, id: PoolId) -> Self {
+        self.pool = id;
+        self
+    }
+
+    #[doc(hidden)]
+    #[deprecated(since = "0.4.12", note = "Use memory pool config")]
     #[inline]
     /// Set read/write buffer params
     ///
     /// By default read buffer is 8kb, write buffer is 8kb
     pub fn buffer_params(
-        mut self,
-        max_read_buf_size: u16,
-        max_write_buf_size: u16,
-        min_buf_size: u16,
+        self,
+        _max_read_buf_size: u16,
+        _max_write_buf_size: u16,
+        _min_buf_size: u16,
     ) -> Self {
-        self.read_hw = max_read_buf_size;
-        self.write_hw = max_write_buf_size;
-        self.lw = min_buf_size;
         self
     }
 
@@ -150,13 +156,11 @@ where
             client_timeout: self.client_timeout,
             client_disconnect: self.client_disconnect,
             handshake_timeout: self.handshake_timeout,
+            pool: self.pool,
             expect: expect.into_factory(),
             upgrade: self.upgrade,
             on_connect: self.on_connect,
             on_request: self.on_request,
-            lw: self.lw,
-            read_hw: self.read_hw,
-            write_hw: self.write_hw,
             _t: PhantomData,
         }
     }
@@ -183,13 +187,11 @@ where
             client_timeout: self.client_timeout,
             client_disconnect: self.client_disconnect,
             handshake_timeout: self.handshake_timeout,
+            pool: self.pool,
             expect: self.expect,
             upgrade: Some(upgrade.into_factory()),
             on_connect: self.on_connect,
             on_request: self.on_request,
-            lw: self.lw,
-            read_hw: self.read_hw,
-            write_hw: self.write_hw,
             _t: PhantomData,
         }
     }
@@ -238,9 +240,7 @@ where
             self.client_timeout,
             self.client_disconnect,
             self.handshake_timeout,
-            self.lw,
-            self.read_hw,
-            self.write_hw,
+            self.pool,
         );
         H1Service::with_config(cfg, service.into_factory())
             .expect(self.expect)
@@ -264,9 +264,7 @@ where
             self.client_timeout,
             self.client_disconnect,
             self.handshake_timeout,
-            self.lw,
-            self.read_hw,
-            self.write_hw,
+            self.pool,
         );
         H2Service::with_config(cfg, service.into_factory()).on_connect(self.on_connect)
     }
@@ -287,9 +285,7 @@ where
             self.client_timeout,
             self.client_disconnect,
             self.handshake_timeout,
-            self.lw,
-            self.read_hw,
-            self.write_hw,
+            self.pool,
         );
         HttpService::with_config(cfg, service.into_factory())
             .expect(self.expect)
