@@ -13,8 +13,8 @@ use crate::http::{
 use crate::server::{Server, ServerBuilder};
 #[cfg(unix)]
 use crate::service::pipeline_factory;
-use crate::time::Seconds;
 use crate::{service::map_config, IntoServiceFactory, Service, ServiceFactory};
+use crate::{time::Seconds, util::PoolId};
 
 use super::config::AppConfig;
 
@@ -24,9 +24,7 @@ struct Config {
     client_timeout: Seconds,
     client_disconnect: Seconds,
     handshake_timeout: Seconds,
-    lw: u16,
-    read_hw: u16,
-    write_hw: u16,
+    pool: PoolId,
 }
 
 /// An HTTP Server.
@@ -86,9 +84,7 @@ where
                 client_timeout: Seconds(5),
                 client_disconnect: Seconds(5),
                 handshake_timeout: Seconds(5),
-                lw: 1024,
-                read_hw: 8 * 1024,
-                write_hw: 8 * 1024,
+                pool: PoolId::P1,
             })),
             backlog: 1024,
             builder: ServerBuilder::default(),
@@ -229,22 +225,27 @@ where
         self
     }
 
+    /// Set memory pool.
+    ///
+    /// Use specified memory pool for memory allocations. By default P1
+    /// memory pool is used.
+    pub fn memory_pool(self, id: PoolId) -> Self {
+        self.config.lock().unwrap().pool = id;
+        self
+    }
+
+    #[doc(hidden)]
+    #[deprecated(since = "0.4.12", note = "Use memory pool config")]
     #[inline]
     /// Set read/write buffer params
     ///
     /// By default read buffer is 8kb, write buffer is 8kb
     pub fn buffer_params(
         self,
-        max_read_buf_size: u16,
-        max_write_buf_size: u16,
-        min_buf_size: u16,
+        _max_read_buf_size: u16,
+        _max_write_buf_size: u16,
+        _min_buf_size: u16,
     ) -> Self {
-        {
-            let mut cfg = self.config.lock().unwrap();
-            cfg.read_hw = max_read_buf_size;
-            cfg.write_hw = max_write_buf_size;
-            cfg.lw = min_buf_size;
-        }
         self
     }
 
@@ -272,7 +273,7 @@ where
                     .keep_alive(c.keep_alive)
                     .client_timeout(c.client_timeout)
                     .disconnect_timeout(c.client_disconnect)
-                    .buffer_params(c.read_hw, c.write_hw, c.lw)
+                    .memory_pool(c.pool)
                     .finish(map_config(factory(), move |_| cfg.clone()))
                     .tcp()
             },
@@ -317,7 +318,7 @@ where
                     .client_timeout(c.client_timeout)
                     .disconnect_timeout(c.client_disconnect)
                     .ssl_handshake_timeout(c.handshake_timeout)
-                    .buffer_params(c.read_hw, c.write_hw, c.lw)
+                    .memory_pool(c.pool)
                     .finish(map_config(factory(), move |_| cfg.clone()))
                     .openssl(acceptor.clone())
             },
@@ -362,7 +363,7 @@ where
                     .client_timeout(c.client_timeout)
                     .disconnect_timeout(c.client_disconnect)
                     .ssl_handshake_timeout(c.handshake_timeout)
-                    .buffer_params(c.read_hw, c.write_hw, c.lw)
+                    .memory_pool(c.pool)
                     .finish(map_config(factory(), move |_| cfg.clone()))
                     .rustls(config.clone())
             },
@@ -485,7 +486,7 @@ where
                 HttpService::build()
                     .keep_alive(c.keep_alive)
                     .client_timeout(c.client_timeout)
-                    .buffer_params(c.read_hw, c.write_hw, c.lw)
+                    .memory_pool(c.pool)
                     .finish(map_config(factory(), move |_| config.clone())),
             )
         })?;
@@ -526,7 +527,7 @@ where
                     HttpService::build()
                         .keep_alive(c.keep_alive)
                         .client_timeout(c.client_timeout)
-                        .buffer_params(c.read_hw, c.write_hw, c.lw)
+                        .memory_pool(c.pool)
                         .finish(map_config(factory(), move |_| config.clone())),
                 )
             },
