@@ -2,14 +2,11 @@ use std::collections::HashMap;
 use std::io::{Read, Write};
 use std::sync::atomic::{AtomicUsize, Ordering};
 use std::sync::Arc;
-use std::time::Duration;
 
 use brotli2::write::BrotliEncoder;
-use bytes::Bytes;
 use coo_kie::Cookie;
 use flate2::{read::GzDecoder, write::GzEncoder, write::ZlibEncoder, Compression};
-use futures::future::ok;
-use futures::stream::once;
+use futures::{future::ok, stream::once};
 use rand::Rng;
 
 use ntex::http::client::error::{JsonPayloadError, SendRequestError};
@@ -20,6 +17,7 @@ use ntex::service::{map_config, pipeline_factory, Service};
 use ntex::web::dev::AppConfig;
 use ntex::web::middleware::Compress;
 use ntex::web::{self, test, App, BodyEncoding, Error, HttpRequest, HttpResponse};
+use ntex::{time::Millis, time::Seconds, util::Bytes};
 
 const STR: &str = "Hello World Hello World Hello World Hello World Hello World \
                    Hello World Hello World Hello World Hello World Hello World \
@@ -59,12 +57,7 @@ async fn test_simple() {
     let bytes = response.body().await.unwrap();
     assert_eq!(bytes, Bytes::from_static(STR.as_ref()));
 
-    let mut response = srv
-        .post("/")
-        .timeout(Duration::from_secs(30))
-        .send()
-        .await
-        .unwrap();
+    let mut response = srv.post("/").timeout(Seconds(30)).send().await.unwrap();
     assert!(response.status().is_success());
 
     // read response
@@ -169,7 +162,7 @@ async fn test_form() {
 async fn test_timeout() {
     let srv = test::server(|| {
         App::new().service(web::resource("/").route(web::to(|| async {
-            ntex::rt::time::sleep(Duration::from_millis(200)).await;
+            ntex::time::sleep(Millis(2000)).await;
             HttpResponse::Ok().body(STR)
         })))
     });
@@ -179,12 +172,12 @@ async fn test_timeout() {
             ntex::connect::Connector::new()
                 .map(|sock| (sock, ntex::http::Protocol::Http1)),
         )
-        .timeout(Duration::from_secs(15))
+        .timeout(Seconds(15))
         .finish();
 
     let client = Client::build()
         .connector(connector)
-        .timeout(Duration::from_millis(50))
+        .timeout(Seconds(1))
         .finish();
 
     let request = client.get(srv.url("/")).send();
@@ -198,18 +191,13 @@ async fn test_timeout() {
 async fn test_timeout_override() {
     let srv = test::server(|| {
         App::new().service(web::resource("/").route(web::to(|| async {
-            ntex::rt::time::sleep(Duration::from_millis(200)).await;
+            ntex::time::sleep(Millis(2000)).await;
             HttpResponse::Ok().body(STR)
         })))
     });
 
-    let client = Client::build()
-        .timeout(Duration::from_millis(50000))
-        .finish();
-    let request = client
-        .get(srv.url("/"))
-        .timeout(Duration::from_millis(50))
-        .send();
+    let client = Client::build().timeout(Seconds(50)).finish();
+    let request = client.get(srv.url("/")).timeout(Seconds(1)).send();
     match request.await {
         Err(SendRequestError::Timeout) => (),
         _ => panic!(),
@@ -238,7 +226,7 @@ async fn test_connection_reuse() {
         )
     });
 
-    let client = Client::build().timeout(Duration::from_secs(10)).finish();
+    let client = Client::build().timeout(Seconds(10)).finish();
 
     // req 1
     let request = client.get(srv.url("/")).send();
@@ -276,7 +264,7 @@ async fn test_connection_force_close() {
         )
     });
 
-    let client = Client::build().timeout(Duration::from_secs(10)).finish();
+    let client = Client::build().timeout(Seconds(10)).finish();
 
     // req 1
     let request = client.get(srv.url("/")).force_close().send();
@@ -314,7 +302,7 @@ async fn test_connection_server_close() {
         )
     });
 
-    let client = Client::build().timeout(Duration::from_secs(10)).finish();
+    let client = Client::build().timeout(Seconds(10)).finish();
 
     // req 1
     let request = client.get(srv.url("/")).send();
@@ -354,7 +342,7 @@ async fn test_connection_wait_queue() {
     });
 
     let client = Client::build()
-        .timeout(Duration::from_secs(30))
+        .timeout(Seconds(30))
         .connector(Connector::default().limit(1).finish())
         .finish();
 
@@ -402,7 +390,7 @@ async fn test_connection_wait_queue_force_close() {
     });
 
     let client = Client::build()
-        .timeout(Duration::from_secs(30))
+        .timeout(Seconds(30))
         .connector(Connector::default().limit(1).finish())
         .finish();
 
@@ -455,7 +443,7 @@ async fn test_no_decompress() {
             })))
     });
 
-    let client = Client::build().timeout(Duration::from_secs(30)).finish();
+    let client = Client::build().timeout(Seconds(30)).finish();
 
     let mut res = client
         .get(srv.url("/"))
@@ -614,11 +602,7 @@ async fn test_client_brotli_encoding_large_random() {
     assert_eq!(bytes, Bytes::from(data.clone()));
 
     // frozen request
-    let request = srv
-        .post("/")
-        .timeout(Duration::from_secs(30))
-        .freeze()
-        .unwrap();
+    let request = srv.post("/").timeout(Seconds(30)).freeze().unwrap();
     assert_eq!(request.get_method(), http::Method::POST);
     assert_eq!(request.get_uri(), srv.url("/").as_str());
     let mut response = request.send_body(data.clone()).await.unwrap();
@@ -656,11 +640,7 @@ async fn test_client_brotli_encoding_large_random() {
     assert_eq!(bytes, Bytes::from(data.clone()));
 
     // frozen request
-    let request = srv
-        .post("/")
-        .timeout(Duration::from_secs(30))
-        .freeze()
-        .unwrap();
+    let request = srv.post("/").timeout(Seconds(30)).freeze().unwrap();
     let mut response = request
         .send_stream(once(ok::<_, JsonPayloadError>(Bytes::from(data.clone()))))
         .await
@@ -844,11 +824,11 @@ async fn client_read_until_eof() {
             }
         }
     });
-    ntex::rt::time::sleep(Duration::from_millis(300)).await;
+    ntex::time::sleep(Millis(300)).await;
 
     // client request
     let req = Client::build()
-        .timeout(Duration::from_secs(30))
+        .timeout(Seconds(30))
         .finish()
         .get(format!("http://{}/", addr).as_str());
     let mut response = req.send().await.unwrap();
